# Peeves

A small layer on the built in unit testing and documentation building frameworks.
Provides little utilities to support testing, like a timer and profiler.
No assurances of reliability, but also not too bad to read the source.
[We also have some (minimal) documentation.](https://mccoygroup.github.io/Peeves/)
Documentation on more of our packages can be found [here](https://mccoygroup.github.io/References/Documentation).

### Installation

We're distributing this via GitHub, so just `git clone` it where you need to like

```console
git clone https://github.com/McCoyGroup/Peeves.git <your_dir>
```

You can also `pip` install if you like. The package name is `mccoygroup-peeves`.

---